@@ -41,6 +41,7 @@
 #include <elf.h>
 #include <asm/unistd.h>
 #include <sys/wait.h>
+#include <fnmatch.h>
 
 #include "list.h"
 
@@ -57,61 +58,6 @@ static const char *default_configs[] =
     "/etc/modprobe.d",
 };
 
-/* From udev_utils_string.h 
- * int strcmp_pattern(const char *p, const char *s)
- */
-int fnmatch(const char *p, const char *s)
-{
-    if (s[0] == '\0') {
-        while (p[0] == '*')
-            p++;
-        return (p[0] != '\0');
-    }
-    switch (p[0]) {
-    case '[':
-        {
-            int not = 0;
-            p++;
-            if (p[0] == '!') {
-                not = 1;
-                p++;
-            }
-            while ((p[0] != '\0') && (p[0] != ']')) {
-                int match = 0;
-                if (p[1] == '-') {
-                    if ((s[0] >= p[0]) && (s[0] <= p[2]))
-                        match = 1;
-                    p += 3;
-                } else {
-                    match = (p[0] == s[0]);
-                    p++;
-                }
-                if (match ^ not) {
-                    while ((p[0] != '\0') && (p[0] != ']'))
-                        p++;
-                    if (p[0] == ']')
-                        return fnmatch(p+1, s+1);
-                }
-            }
-        }
-        break;
-    case '*':
-        if (fnmatch(p, s+1))
-            return fnmatch(p+1, s);
-        return 0;
-    case '\0':
-        if (s[0] == '\0') {
-            return 0;
-        }
-        break;
-    default:
-        if ((p[0] == s[0]) || (p[0] == '?'))
-            return fnmatch(p+1, s+1);
-        break;
-    }
-    return 1;
-}
-
 void *grab_fd(int fd, unsigned long *size)
 {
     struct stat st;
@@ -598,7 +544,7 @@ static const char *find_command(const char *modname,
                                 const struct module_command *commands)
 {
     while (commands) {
-        if (fnmatch(commands->modulename, modname) == 0)
+        if (fnmatch(commands->modulename, modname, 0) == 0)
             return commands->command;
         commands = commands->next;
     }
@@ -874,7 +820,7 @@ static int read_config_file(const char *filename,
 
             if (!wildcard || !realname)
                 grammar(cmd, filename, linenum);
-            else if (fnmatch(wildcard,name) == 0)
+            else if (fnmatch(wildcard,name,0) == 0)
                 *aliases = add_alias(realname, *aliases);
         } else if (strcmp(cmd, "include") == 0) {
             struct module_alias *newalias = NULL;
